@@ -25,7 +25,7 @@ usage()
 
 	printf "\nNote that you must be located in the directory that is up one depth
 	from the source directory of interest, providing a relative path to it. The
-	destination directory might be absolute." 
+	destination directory might be absolute."
 
 	printf "A typical invocation might be:\n"
 	printf "$0 <relative path source dir> <full path dest dir>\n\n"
@@ -105,9 +105,9 @@ dest_tree_dir=$2
 
 
 for file in $(find ${src_tree_dir} -type f)
-do 
+do
 
-	printf "Working on ${file}... \n"
+	printf "Working on ${file}... "
 
 	dir_name=$(dirname ${file})
 	base_name=$(basename ${file})
@@ -127,16 +127,12 @@ do
 				printf "mkdir -p ${dest_tree_dir}/${dir_name}\n"
 				mkdir -p ${dest_tree_dir}/${dir_name}
 
-				printf "cp ${file} ${dest_tree_dir}/${file}\n"
-				cp ${file} ${dest_tree_dir}/${file}
+				printf "cp -v ${file} ${dest_tree_dir}/${file}\n"
+				cp -v ${file} ${dest_tree_dir}/${file}
 
 			else
 
-<<<<<<< HEAD
-				printf "Dry run, should be copying ${file} to ${dest_tree_dir}/${file}.\n"
-=======
-				printf "Dry run, not copying ${file} to ${dest_tree_dir}/${file}.\n"
->>>>>>> 4b1f6a2 (Reinstate the script.)
+				printf "Dry run, would be copying ${file} to ${dest_tree_dir}/${file}.\n"
 
 			fi
 
