@@ -35,7 +35,6 @@
 #ifdef WIN32
 
 #pragma GCC warning "WIN32 is defined"
-
 #define _WIN32_WINNT 0x0600
 #define WIN32_LEAN_AND_MEAN
 // #define NOMINMAX
@@ -45,10 +44,8 @@
 // #include <wincrypt.h>
 #include <winternl.h>
 #include <Psapi.h>
-
 #include <boost/nowide/convert.hpp>
 #include <boost/noncopyable.hpp>
-
 #else // ifdef WIN32
 
 #pragma GCC warning "WIN32 is NOT defined"
@@ -64,22 +61,18 @@
 #include <sys/ioctl.h>
 
 // Begin added PAPPSO for MXE
-#endif
+#endif // ifndef MXE
 // End added PAPPSO for MXE
 
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <sys/stat.h>
 #include <unistd.h>
-
 #ifndef MAX_PATH
-
 #define MAX_PATH 255
-
-#endif
-
+#endif // MAX_PATH
 #endif // #else // ifdef WIN32
 
-
 #include <boost/utility/singleton.hpp>
 #include "pwiz/utility/misc/random_access_compressed_ifstream.hpp"
 #include <boost/filesystem/detail/utf8_codecvt_facet.hpp>
@@ -89,12 +82,12 @@
 // #include <boost/xpressive/xpressive.hpp>
 #include <iostream>
 #include <thread>
+// #include <filesystem>
 
 using std::runtime_error;
 using std::string;
 using std::vector;
 
-
 namespace
 {
 
@@ -116,7 +109,7 @@ class UTF8_BoostFilesystemPathImbuer
 #ifdef WIN32
 #define STATUS_INFO_LENGTH_MISMATCH 0xc0000004
 
-#define SystemHandleInformation 16
+#define SystemHandleInformation     16
 
 extern "C"
 {
@@ -136,35 +129,12 @@ extern "C"
     ACCESS_MASK GrantedAccess;
   };
 
-// Begin F. Rusconi -- This define is performed in CMakeStuff/systemUname.cmake
-#ifdef WIN10MINGW64
-
-  // In file /c/msys64/mingw64/include/winternl.h
-  // this is what is declared:
-  // typedef struct _SYSTEM_HANDLE_INFORMATION {
-  //   ULONG Count;
-  //   SYSTEM_HANDLE_ENTRY Handle[1];
-  // } SYSTEM_HANDLE_INFORMATION, *PSYSTEM_HANDLE_INFORMATION;
-
-  // This declaration clashes with the above.
-
-  struct PWIZ_SYSTEM_HANDLE_INFORMATION
-  {
-    ULONG HandleCount;
-    SYSTEM_HANDLE Handles[1];
-  };
-
-#else
-
   struct SYSTEM_HANDLE_INFORMATION
   {
     ULONG HandleCount;
     SYSTEM_HANDLE Handles[1];
   };
 
-#endif
-  // End F. Rusconi
-
   enum SECTION_INHERIT
   {
     ViewShare = 1,
@@ -203,33 +173,16 @@ extern "C"
     ULONG ObjectInformationLength,
     PULONG ReturnLength);
 
-
   PVOID
   GetLibraryProcAddress(PSTR LibraryName, PSTR ProcName)
   {
-
-    // Begin added F. Rusconi
-#ifdef WIN10MINGW64
-    return (void *)GetProcAddress(GetModuleHandleA(LibraryName), ProcName);
-#else
     return GetProcAddress(GetModuleHandleA(LibraryName), ProcName);
-#endif
-    // End added F. Rusconi
   }
 }
 
-// Begin added F. Rusconi
-#ifdef WIN10MINGW64
-int
-GetFileHandleTypeNumber(PWIZ_SYSTEM_HANDLE_INFORMATION *handleInfos)
-{
-#else
 int
 GetFileHandleTypeNumber(SYSTEM_HANDLE_INFORMATION *handleInfos)
 {
-#endif
-  // End added F. Rusconi
-
   DWORD currentProcessId = GetCurrentProcessId();
   wstring fileType       = L"File";
   std::vector<BYTE> typeInfoBytes(sizeof(PUBLIC_OBJECT_TYPE_INFORMATION));
@@ -286,10 +239,11 @@ GetFileHandleTypeNumber(SYSTEM_HANDLE_INFORMATION *handleInfos)
   if(handlesPerType.empty())
     return 0;
 
-  auto typeMode = std::max_element(
-    handlesPerType.begin(),
-    handlesPerType.end(),
-    [](const auto &a, const auto &b) { return a.second < b.second; });
+  auto typeMode = std::max_element(handlesPerType.begin(),
+                                   handlesPerType.end(),
+                                   [](const auto &a, const auto &b) {
+                                     return a.second < b.second;
+                                   });
   return typeMode->first;
 }
 
@@ -345,7 +299,6 @@ running_on_wine()
 #endif
 }
 
-
 PWIZ_API_DECL void
 force_close_handles_to_filepath(const std::string &filepath,
                                 bool closeMemoryMappedSections) noexcept(true)
@@ -391,15 +344,7 @@ force_close_handles_to_filepath(const std::string &filepath,
     }
 
   NTSTATUS status = 0;
-
-// Begin added F. Rusconi
-#ifdef WIN10MINGW64
-  DWORD dwSize = sizeof(PWIZ_SYSTEM_HANDLE_INFORMATION);
-#else
-  DWORD dwSize = sizeof(SYSTEM_HANDLE_INFORMATION);
-#endif
-  // End added F. Rusconi
-
+  DWORD dwSize    = sizeof(SYSTEM_HANDLE_INFORMATION);
   vector<BYTE> pInfoBytes(dwSize);
 
   do
@@ -438,15 +383,7 @@ force_close_handles_to_filepath(const std::string &filepath,
       return;
     }
 
-// Begin added F. Rusconi
-#ifdef WIN10MINGW64
-  auto pInfo =
-    reinterpret_cast<PWIZ_SYSTEM_HANDLE_INFORMATION *>(pInfoBytes.data());
-#else
   auto pInfo = reinterpret_cast<SYSTEM_HANDLE_INFORMATION *>(pInfoBytes.data());
-#endif
-  // End added F. Rusconi
-
   int fileHandleType = GetFileHandleTypeNumber(pInfo);
   if(fileHandleType == 0)
     {
@@ -600,7 +537,6 @@ force_close_handles_to_filepath(const std::string &filepath,
 #endif
 }
 
-
 PWIZ_API_DECL void
 enable_utf8_path_operations()
 {
@@ -608,7 +544,7 @@ enable_utf8_path_operations()
 }
 
 // Begin added PAPPSO for MXE
-#ifndef MXE
+#if !defined(MXE) && !defined(WIN10MINGW64)
 // End added PAPPSO for MXE
 
 PWIZ_API_DECL int
@@ -620,7 +556,7 @@ expand_pathmask(const bfs::path &pathmask, vector<bfs::path> &matchingPaths)
   int matchingPathCount = 0;
 
 #ifdef WIN32
-  path maskParentPath = pathmask.branch_path();
+  path maskParentPath = pathmask.parent_path();
   WIN32_FIND_DATAW fdata;
   HANDLE srcFile =
     FindFirstFileExW(boost::nowide::widen(pathmask.string()).c_str(),
@@ -678,53 +614,6 @@ expand_pathmask(const bfs::path &pathmask, vector<bfs::path> &matchingPaths)
 #endif
 // End added PAPPSO for MXE
 
-namespace
-{
-void
-copy_recursive(const bfs::path &from, const bfs::path &to)
-{
-  bfs::copy_directory(from, to);
-
-  for(bfs::directory_entry &entry : bfs::directory_iterator(from))
-    {
-      bfs::file_status status = entry.status();
-      if(status.type() == bfs::directory_file)
-        copy_recursive(entry.path(), to / entry.path().filename());
-      else if(status.type() == bfs::regular_file)
-        bfs::copy_file(entry.path(), to / entry.path().filename());
-      else
-        throw bfs::filesystem_error(
-          "[copy_directory] invalid path type",
-          entry.path(),
-          boost::system::error_code(
-            boost::system::errc::no_such_file_or_directory,
-            boost::system::system_category()));
-    }
-}
-
-void
-copy_recursive(const bfs::path &from,
-               const bfs::path &to,
-               boost::system::error_code &ec)
-{
-  bfs::copy_directory(from, to, ec);
-  if(ec.value() != 0)
-    return;
-
-  for(bfs::directory_entry &entry : bfs::directory_iterator(from))
-    {
-      bfs::file_status status = entry.status(ec);
-      if(status.type() == bfs::directory_file)
-        copy_recursive(entry.path(), to / entry.path().filename(), ec);
-      else if(status.type() == bfs::regular_file)
-        bfs::copy_file(entry.path(), to / entry.path().filename(), ec);
-      else if(ec.value() != 0)
-        ec.assign(boost::system::errc::no_such_file_or_directory,
-                  boost::system::system_category());
-    }
-}
-} // namespace
-
 PWIZ_API_DECL void
 copy_directory(const bfs::path &from,
                const bfs::path &to,
@@ -754,24 +643,25 @@ copy_directory(const bfs::path &from,
   if(recursive)
     {
       if(ec != NULL)
-        copy_recursive(from, to, *ec);
+        bfs::copy(from, to, bfs::copy_options::recursive, *ec);
       else
-        copy_recursive(from, to);
+        bfs::copy(from, to, bfs::copy_options::recursive);
     }
   else
     {
       if(ec != NULL)
-        bfs::copy_directory(from, to, *ec);
+        bfs::copy(from, to, *ec);
       else
-        bfs::copy_directory(from, to);
+        bfs::copy(from, to);
     }
 }
 
 
+
 using boost::uintmax_t;
 
 template <typename T>
-struct double3_policy : boost::spirit::karma::real_policies<T>
+struct double3_policy: boost::spirit::karma::real_policies<T>
 {
   // up to 3 digits total, but no unnecessary precision
   static unsigned int
@@ -781,6 +671,7 @@ struct double3_policy : boost::spirit::karma::real_policies<T>
     fracPart = modf(n, &intPart);
     return fracPart < 0.005 ? 0 : n < 10 ? 2 : n < 100 ? 1 : 0;
   }
+
   static bool
   trailing_zeros(T)
   {
@@ -836,7 +727,7 @@ abbreviate_byte_size(uintmax_t byteSize, ByteSizeAbbreviation abbreviationType)
     {
       byteSizeDbl = (double)byteSize / G;
       // byteSizeDbl = round(byteSizeDbl * 100) / 100;
-      suffix = GS;
+      suffix      = GS;
     }
   else if(byteSize >= M)
     {
@@ -864,7 +755,6 @@ abbreviate_byte_size(uintmax_t byteSize, ByteSizeAbbreviation abbreviationType)
   return std::string(&buffer[0], p) + suffix;
 }
 
-
 PWIZ_API_DECL bool
 isHTTP(const string &s)
 {
@@ -878,18 +768,21 @@ isHTTP(const string &s)
   return bal::istarts_with(s, "http:") || bal::istarts_with(s, "https:");
 }
 
+
 #ifdef WIN32
 namespace
 {
-struct FileWrapper : boost::noncopyable
+struct FileWrapper: boost::noncopyable
 {
-  FileWrapper(HANDLE h) : h(h)
+  FileWrapper(HANDLE h): h(h)
   {
   }
+
   ~FileWrapper()
   {
     CloseHandle(h);
   }
+
   bool
   operator==(const HANDLE &rhs)
   {
@@ -962,7 +855,6 @@ read_file_header(const string &filepath, size_t length)
   return head;
 }
 
-
 PWIZ_API_DECL void
 check_path_length(const string &path)
 {
@@ -978,12 +870,12 @@ check_path_length(const string &path)
 #endif
 }
 
-
 PWIZ_API_DECL
-TemporaryFile::TemporaryFile(const string &extension)
+TemporaryFile::TemporaryFile(const string &filenamePrefix,
+                             const string &extension)
 {
   filepath = bfs::temp_directory_path() /
-             bfs::unique_path("%%%%%%%%%%%%%%%%" + extension);
+             bfs::unique_path(filenamePrefix + "%%%%%%%%%%%%%%%%" + extension);
 }
 
 PWIZ_API_DECL TemporaryFile::~TemporaryFile()
@@ -993,9 +885,8 @@ PWIZ_API_DECL TemporaryFile::~TemporaryFile()
 }
 
 // Begin added PAPPSO for MXE
-#ifndef MXE
+#if !defined(MXE) && !defined(WIN10MINGW64)
 // End added PAPPSO for MXE
-
 PWIZ_API_DECL std::pair<int, int>
 get_console_bounds(const std::pair<int, int> &defaultBounds)
 {
